==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fbranch.h <==
// abstract class soot.coffi.Instruction_branch

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fbranch_H_
#define _JC_soot_coffi_Instruction__5fbranch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_coffi_ByteCode$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fbranch$sub_refs	_jc_soot_coffi_Instruction__5fbranch$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	_jc_soot_coffi_Instruction__5fbranch$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fbranch$refs	_jc_soot_coffi_Instruction__5fbranch$refs;
typedef struct _jc_soot_coffi_Instruction__5fbranch$nonrefs	_jc_soot_coffi_Instruction__5fbranch$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fbranch$object	_jc_soot_coffi_Instruction__5fbranch$object;

typedef const struct _jc_soot_coffi_Instruction__5fbranch$vmethods	_jc_soot_coffi_Instruction__5fbranch$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fbranch$vtable	_jc_soot_coffi_Instruction__5fbranch$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fbranch$vtype	_jc_soot_coffi_Instruction__5fbranch$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fbranch$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, jbyte);

// Virtual methods
extern _jc_object_array *_jc_soot_coffi_Instruction__5fbranch$method$branchpoints$0387b0529fae51a0(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, struct _jc_soot_coffi_Instruction$object *);
extern void _jc_soot_coffi_Instruction__5fbranch$method$offsetToPointer$cf6c4bc72d76f691(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, struct _jc_soot_coffi_ByteCode$object *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fbranch$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fbranch$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fbranch$method_info$branchpoints$0387b0529fae51a0;
extern _jc_method _jc_soot_coffi_Instruction__5fbranch$method_info$offsetToPointer$cf6c4bc72d76f691;
extern _jc_method _jc_soot_coffi_Instruction__5fbranch$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_coffi_Instruction__5fbranch$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fbranch$vmethods {
	_jc_object_array	*(*branchpoints$0387b0529fae51a0)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, struct _jc_soot_coffi_Instruction$object *);
	void	(*offsetToPointer$cf6c4bc72d76f691)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, struct _jc_soot_coffi_ByteCode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *);
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fbranch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fbranch$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fbranch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fbranch$sub_refs {
	struct _jc_soot_coffi_Instruction$object	*target;
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fbranch$refs {
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs {
	jint	arg__5fi;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fbranch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fbranch$object {
	_jc_soot_coffi_Instruction__5fbranch$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fbranch$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fbranch$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fbranch$vtype _jc_soot_coffi_Instruction__5fbranch$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fbranch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fbranch$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fbranch_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fbranch.h <==
// abstract class soot.coffi.Instruction_branch

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fbranch_H_
#define _JC_soot_coffi_Instruction__5fbranch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_coffi_ByteCode$object;
struct _jc_soot_coffi_Instruction$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fbranch$sub_refs	_jc_soot_coffi_Instruction__5fbranch$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	_jc_soot_coffi_Instruction__5fbranch$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fbranch$refs	_jc_soot_coffi_Instruction__5fbranch$refs;
typedef struct _jc_soot_coffi_Instruction__5fbranch$nonrefs	_jc_soot_coffi_Instruction__5fbranch$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fbranch$object	_jc_soot_coffi_Instruction__5fbranch$object;

typedef const struct _jc_soot_coffi_Instruction__5fbranch$vmethods	_jc_soot_coffi_Instruction__5fbranch$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fbranch$vtable	_jc_soot_coffi_Instruction__5fbranch$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fbranch$vtype	_jc_soot_coffi_Instruction__5fbranch$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fbranch$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, jbyte) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_soot_coffi_Instruction__5fbranch$method$branchpoints$0387b0529fae51a0(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_Instruction__5fbranch$method$offsetToPointer$cf6c4bc72d76f691(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, struct _jc_soot_coffi_ByteCode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fbranch$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fbranch$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fbranch$method_info$branchpoints$0387b0529fae51a0;
extern _jc_method _jc_soot_coffi_Instruction__5fbranch$method_info$offsetToPointer$cf6c4bc72d76f691;
extern _jc_method _jc_soot_coffi_Instruction__5fbranch$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_coffi_Instruction__5fbranch$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fbranch$vmethods {
	_jc_object_array	*(*branchpoints$0387b0529fae51a0)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, struct _jc_soot_coffi_Instruction$object *) _JC_JCNI_ATTR;
	void	(*offsetToPointer$cf6c4bc72d76f691)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, struct _jc_soot_coffi_ByteCode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fbranch$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fbranch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fbranch$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fbranch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fbranch$sub_refs {
	struct _jc_soot_coffi_Instruction$object	*target;
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fbranch$refs {
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs {
	jint	arg__5fi;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fbranch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fbranch$object {
	_jc_soot_coffi_Instruction__5fbranch$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fbranch$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fbranch$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fbranch$vtype _jc_soot_coffi_Instruction__5fbranch$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fbranch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fbranch$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fbranch_H_ */
